package com.xkrs.service.impl;

import com.xkrs.common.encapsulation.PromptMessageEnum;
import com.xkrs.dao.BankCardDao;
import com.xkrs.dao.BusinessDao;
import com.xkrs.model.entity.BankCardEntity;
import com.xkrs.model.entity.BusinessEntity;
import com.xkrs.model.qo.BankCardQo;
import com.xkrs.model.qo.BusinessQo;
import com.xkrs.service.MerchantSettlementService;
import com.xkrs.utils.DateTimeUtil;
import com.xkrs.utils.PhotoUtil;
import com.xkrs.utils.VerifyBankCardUtil;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.time.LocalDateTime;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import static com.xkrs.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @Author: XinYi Song
 * @Date: 2021/12/14 9:52
 * 商家模块
 */
@Service
public class MerchantSettlementServiceImpl implements MerchantSettlementService {

    @Resource
    private BusinessDao businessDao;

    @Resource
    private BankCardDao bankCardDao;

    /**
     * 商家入驻
     * @param businessQo
     * @param businessPhoto
     * @param businessLicense
     * @param bankCardQos
     * @param
     * @return
     */
    @Override
    public String merchantSettlement(BusinessQo businessQo, MultipartFile businessPhoto, MultipartFile businessLicense, List<BankCardQo> bankCardQos) throws IOException {
        Locale locale = LocaleContextHolder.getLocale();
        BusinessEntity byBusinessName = businessDao.findByBusinessName(businessQo.getBusinessName());
        if(byBusinessName != null){
            return outputEncapsulationObject(PromptMessageEnum.FILE_EXISTS,"您已入驻，请勿重复入驻或提交！",locale);
        }
        BusinessEntity byBusinessPhone = businessDao.findByBusinessPhone(businessQo.getBusinessPhone());
        if(byBusinessPhone != null){
            return outputEncapsulationObject(PromptMessageEnum.FILE_EXISTS,"您已入驻，请勿重复入驻或提交！",locale);
        }
        if(businessPhoto == null){
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE,"商家图片不能为空！",locale);
        }
        if(businessLicense == null){
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE,"营业执照不能为空！",locale);
        }
        // 上传商家图片
        //String busPhoto = PhotoUtil.memoryPhoto(businessPhoto);
        // 上传商家营业执照
        //String photo = PhotoUtil.memoryPhoto(businessLicense);
        for(BankCardQo bankCardQo : bankCardQos){
            Map<String, Object> stringObjectMap = VerifyBankCardUtil.checkBankCar(bankCardQo.getBankCardNumber());
            if(!((Boolean) stringObjectMap.get("card")) || "findNotName".equals(stringObjectMap.get("cardName").toString())){
                return outputEncapsulationObject(PromptMessageEnum.DATA_WRONG,"银行卡信息有误，请检查重新填写！",locale);
            }
            BankCardEntity bankCardEntity = new BankCardEntity();
            bankCardEntity.setBankCardNumber(bankCardQo.getBankCardNumber());
            bankCardEntity.setAccountBank(bankCardQo.getAccountBank());
            bankCardEntity.setBankName(stringObjectMap.get("cardName").toString());
//            bankCardEntity.setBusinessId(businessId);
            bankCardEntity.setBusinessPhone(businessQo.getBusinessPhone());
            bankCardDao.save(bankCardEntity);
        }
        BusinessEntity businessEntity = new BusinessEntity();
        businessEntity.setBusinessName(businessQo.getBusinessName());
        businessEntity.setBusinessPro(businessQo.getBusinessPro());
        businessEntity.setBusinessCity(businessQo.getBusinessCity());
        businessEntity.setBusinessCountry(businessQo.getBusinessCountry());
        businessEntity.setBusinessAddress(businessQo.getBusinessAddress());
        businessEntity.setBusinessPhone(businessQo.getBusinessPhone());
        businessEntity.setBusinessPhoto(businessQo.getBusinessPhoto());
        businessEntity.setBusinessLicense(businessQo.getBusinessLicense());
        businessEntity.setBusinessDiscount(businessQo.getBusinessDiscount());
        businessEntity.setHeadIdentifier(businessQo.getHeadIdentifier());
        businessEntity.setBusinessType("0");
        businessEntity.setSettleInTime(DateTimeUtil.dateTimeToString(LocalDateTime.now()));
        businessDao.save(businessEntity);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"入驻成功！",locale);
    }

    /**
     * 通过状态查询商家入驻的信息
     * @param type
     * @return
     */
    @Override
    public String findAllByBusinessType(String type) {
        Locale locale = LocaleContextHolder.getLocale();
        List<BusinessEntity> allByBusinessType = businessDao.findAllByBusinessType(type);
        if(allByBusinessType == null || allByBusinessType.size() == 0){
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE,"暂时没有您所需要的商家的信息！",locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,allByBusinessType,locale);
    }

    /**
     * 根据省市区查询审核通过的商家的信息
     * @param countyName
     * @param keepType
     * @return
     */
    @Override
    public String findAllByCountyName(String countyName, String keepType) {
        return null;
    }

    /**
     * 根据商家用户id查询入驻信息
     * @param businessId
     * @return
     */
    @Override
    public String findBusinessById(Integer businessId) {
        Locale locale = LocaleContextHolder.getLocale();
        BusinessEntity byBusinessId = businessDao.findByBusinessId(businessId);
        if(byBusinessId == null){
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE,"你还未入驻，请先入驻！",locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,byBusinessId,locale);
    }
}
