package com.xkrs.utils;

import com.xkrs.dao.ProductDao;
import com.xkrs.model.entity.ProductEntity;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * @author XinYi Song
 */

@Component
public class Query {

    @Resource
    private ProductDao productDao;

    /**
     * 查看要审核的商品信息
     * @param businessId
     * @param productCounty
     * @param reviewType
     * @return
     */
    public List<ProductEntity> selectProductCounty(Integer businessId, String productCity, String productCounty, String reviewType) {
        Specification<ProductEntity> specification = new Specification<ProductEntity>() {
            @Override
            public Predicate toPredicate(Root<ProductEntity> root, CriteriaQuery<?> criteriaQuery, CriteriaBuilder criteriaBuilder) {
                List<Predicate> list = new ArrayList<>();
                if(businessId != null){
                    list.add(criteriaBuilder.equal(root.get("businessId").as(Integer.class), businessId));
                }
                if(productCity != null && !"".equals(productCity)){
                    list.add(criteriaBuilder.equal(root.get("productCity").as(String.class), productCity));
                }
                if(productCounty != null && !"".equals(productCounty)){
                    list.add(criteriaBuilder.equal(root.get("productCounty").as(String.class), productCounty));
                }
                if(reviewType != null && !"".equals(reviewType)){
                    list.add(criteriaBuilder.equal(root.get("reviewType").as(String.class), reviewType));
                }
                Predicate[] predicates = new Predicate[list.size()];
                return criteriaBuilder.and(list.toArray(predicates));
            }
        };
        return productDao.findAll(specification);
    }

    /**
     * 查看商品信息
     * @param businessId
     * @param productCounty
     * @param shelfType
     * @return
     */
    public List<ProductEntity> selectAllProduct(Integer businessId, String productCounty, String shelfType) {
        Specification<ProductEntity> specification = new Specification<ProductEntity>() {
            @Override
            public Predicate toPredicate(Root<ProductEntity> root, CriteriaQuery<?> criteriaQuery, CriteriaBuilder criteriaBuilder) {
                List<Predicate> list = new ArrayList<>();
                if(businessId != null){
                    list.add(criteriaBuilder.equal(root.get("businessId").as(Integer.class), businessId));
                }
                if(productCounty != null && !"".equals(productCounty)){
                    list.add(criteriaBuilder.equal(root.get("productCounty").as(String.class), productCounty));
                }
                if(shelfType != null && !"".equals(shelfType)){
                    list.add(criteriaBuilder.equal(root.get("shelfType").as(String.class), shelfType));
                }
                Predicate[] predicates = new Predicate[list.size()];
                return criteriaBuilder.and(list.toArray(predicates));
            }
        };
        return productDao.findAll(specification);
    }


}